pub struct SpeedtestConfig {
pub config_url: Option<Url>,
pub large_download_url: Url,
pub small_download_url: Url,
pub upload_url: Url,
pub latency: LatencyConfigOpts,
pub rpm: RpmConfigOpts,
}Fields
config_url: Option<Url>The endpoint to get the responsiveness config from. Should be JSON in the form:
{
"version": number,
"test_endpoint": string?,
"urls": {
"small_https_download_url": string,
"large_https_download_url": string,
"https_upload_url": string
}
}large_download_url: UrlThe large file endpoint which should be multiple GBs.
small_download_url: UrlThe small file endpoint which should be very small, only a few bytes.
upload_url: UrlThe upload url which accepts an arbitrary amount of data.
latency: LatencyConfigOptsrpm: RpmConfigOptsTrait Implementations
Sourceimpl Debug for SpeedtestConfig
impl Debug for SpeedtestConfig
Sourceimpl Default for SpeedtestConfig
impl Default for SpeedtestConfig
Sourcefn default() -> Self
fn default() -> Self
Return SpeedtestConfig { config_url: Default::default(), large_download_url: "https://h3.speed.cloudflare.com/__down?bytes=10000000000".parse().unwrap(), small_download_url: "https://h3.speed.cloudflare.com/__down?bytes=10".parse().unwrap(), upload_url: "https://h3.speed.cloudflare.com/__up".parse().unwrap(), latency: Default::default(), rpm: Default::default() }
Sourceimpl<'de> Deserialize<'de> for SpeedtestConfigwhere
SpeedtestConfig: Default,
impl<'de> Deserialize<'de> for SpeedtestConfigwhere
SpeedtestConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more